@@ -64,7 +64,12 @@ from bcolz.toplevel import (
 from bcolz.chunked_eval import eval
 from bcolz.defaults import defaults
 from bcolz.version import __version__
-from bcolz.tests import test
+try:
+    from bcolz.tests import test
+except ImportError:
+    def test(*args, **kwargs):
+        print("Could not import tests.\n"
+              "If on Python2.6 please install unittest2")
 
 
 def get_git_descrtiption(path_):
@@ -80,7 +85,7 @@ def get_git_descrtiption(path_):
 
     # make an absolute path if required, for example when running in a clone
     if not path.isabs(path_):
-        path_ = path.join(os.environ['PWD'], path_)
+        path_ = path.join(os.getcwd(), path_)
     # look up the commit using subprocess and git describe
     try:
         # redirect stderr to stdout to make sure the git error message in case
